/********************************************************
 *
 *  Copyright (c) 2015 Sony Corporation
 *
 ********************************************************/

#ifndef __SGDMA_REGS_H__
#define __SGDMA_REGS_H__


#define IO_MAP_OFFSET_CRA           0x00000000
#define IO_MAP_OFFSET_CRA_IRQ_STS   0x00000040
#define IO_MAP_OFFSET_CRA_IRQ_CTL   0x00000050
#define IO_MAP_OFFSET_CRA_ATT       0x00001000

#define IO_MAP_OFFSET_CSR           0x00004000
#define IO_MAP_OFFSET_DESCRIPTOR    0x00004020
#define IO_MAP_OFFSET_RESET         0x00004060
#define IO_MAP_OFFSET_STATUS        0x00004070

#define IO_MAP_OFFSET_DDR_CTRL      0x00010000

typedef struct {
    u8  rsvd01[0x0040];
    u32 cra_irq_status;   // 0x0040
    u8  rsvd02[0x000c];
    u32 cra_irq_control;  // 0x0050
    u8  rsvd03[0x000c];
    u8  rsvd04[0x0fa0];   // 0x0060
    u32 a2p_addr_l0;      // 0x1000
    u32 a2p_addr_h0;
    u32 a2p_addr_l1;
    u32 a2p_addr_h1;
    u8  rsvd05[0x2ff0];
    u8  rsvd06[0x0050];   // 0x4000
    u32 dma_reset;        // 0x4050
    u8  rsvd07[0x000c];
    u8  rsvd08[0x0ea0];   // 0x4060
    u32 intr_data;        // 0x4F00
    u32 intr_dir;         // 0x4F04
    u32 intr_mask;        // 0x4F08
    u32 intr_edge;        // 0x4F0C
    u8  rsvd09[0x00f0];
    u32 intr_enable;      // 0x5000
    u8  rsvd0a[0x000c];
    u32 rx_ctrl;          // 0x5010
    u8  rsvd0b[0x000c];
    u32 tx_ctrl;          // 0x5020
    u8  rsvd0c[0x000c];
} PcieCraReg_t;

#define IO_MAP_OFFSET_FPGA_DDR      0x10000000

typedef struct {
    u32  ctrl;
    u8   rsvd00[0x001c];
    u32  size;
    u8   rsvd01[0x000c];
    u32  addr_u;
    u8   rsvd02[0x000c];
    u32  addr_l;
    u8   rsvd03[0x000c];
} PcieDdrReg_t;

typedef struct {
    u32 status;
    u32 control;
    u16 read_fill;
    u16 write_fill;
    u16 resp_fill;
    u16 rsv0;

    u16 r_seq_num;
    u16 w_seq_num;
    u32 rsv1[3];

    u8  rsv2[0x40];

    u32 fpga_reset;
    u32 rsv3[3];

#define FPGA_STS_BUSY_DDR_W BIT(0)
#define FPGA_STS_BUSY_DDR_R BIT(1)
#define FPGA_STS_BUSY_QUEUE BIT(2)
#define FPGA_STS_BUSY_CACHE BIT(3)
    u32 fpga_status;
    u32 rsv4[3];
} MsgdmaReg_t;

#define MSGDMA_SCR_STS_MASK       0x03ff
#define MSGDMA_SCR_STS_BUSY       BIT(0)
#define MSGDMA_SCR_STS_DESC_EMPTY BIT(1)
#define MSGDMA_SCR_STS_DESC_FULL  BIT(2)
#define MSGDMA_SCR_STS_RESP_EMPTY BIT(3)
#define MSGDMA_SCR_STS_RESP_FULL  BIT(4)
#define MSGDMA_SCR_STS_STOPPED    BIT(5)
#define MSGDMA_SCR_STS_RESETTING  BIT(6)
#define MSGDMA_SCR_STS_ERROR      BIT(7)
#define MSGDMA_SCR_STS_EL_TERM    BIT(8)
#define MSGDMA_SCR_STS_IRQ        BIT(9)

#define MSGDMA_SCR_CTRL_STOP      BIT(0)
#define MSGDMA_SCR_CTRL_RESET     BIT(1)
#define MSGDMA_SCR_CTRL_ERROR     BIT(2)
#define MSGDMA_SCR_CTRL_EL_TERM   BIT(3)
#define MSGDMA_SCR_CTRL_INT_EN    BIT(4)
#define MSGDMA_SCR_CTRL_STOP_DESC BIT(5)


#endif /* __SGDMA_REGS_H__ */
